# Color system

⚠️ The color system is currently an unstable API, and is subject to change in non-major releases of Polaris react. Please use with caution.

## Table of contents

- [surface](#surface)
- [onSurface](#onSurface)
- [interactive](#interactive)
- [secondary](#secondary)
- [primary](#primary)
- [critical](#critical)
- [warning](#warning)
- [highlight](#highlight)
- [success](#success)
- [decorative](#decorative)
- [Overrides](#Overrides)

## surface

[↑ Back to top](#table-of-contents)

The surface role is used for the backgrounds of the UI. With a light color scheme, surface colors are nearly white, while in a dark color scheme, surface colors are nearly black. The color passed to the surface role impacts the rest of the color roles and their variants, adjusting them for light or dark contexts.

| CSS variable                             | Description                                                                                                                           | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ---------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-background</pre>                | For use as a background color, in components such as Page and Frame backgrounds.                                                      | ![](https://www.gifpng.com/64x64/fafafa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fafafa | ![](https://www.gifpng.com/64x64/0c0d0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#0c0d0e |
| <pre>--p-surface</pre>                   | For use as a background color, in components such as Card, Modal, and Popover.                                                        | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/202122/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#202122 |
| <pre>--p-surface-subdued</pre>           | For use as a subdued background color, in components such as Card, Modal, and Popover.                                                | ![](https://www.gifpng.com/64x64/fafafa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fafafa | ![](https://www.gifpng.com/64x64/1b1d1d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#1b1d1d |
| <pre>--p-surface-hovered</pre>           | For use as a surface color on interactive elements such as resource list items and action list items when in a hovered state.         | ![](https://www.gifpng.com/64x64/f2f3f3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#f2f3f3 | ![](https://www.gifpng.com/64x64/2f3032/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#2f3032 |
| <pre>--p-surface-pressed</pre>           | For use as a surface color on interactive elements such as resource list items and action list items when in a pressed state.         | ![](https://www.gifpng.com/64x64/e1e3e5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#e1e3e5 | ![](https://www.gifpng.com/64x64/3d3f42/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#3d3f42 |
| <pre>--p-backdrop</pre>                  | For use as the background color of the backdrop component for navigation and modal. This color has an alpha of `0.5`.                 | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#000000 | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#000000 |
| <pre>--p-overlay</pre>                   | For use as the background color of elements which lay on top of surfaces to obscure their contents. This color has an alpha of `0.5`. | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/212121/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#212121 |
| <pre>--p-shadow-from-ambient-light</pre> | For use in building shadows for popovers, cards, and modals. This color has an alpha of `0.05`.                                       | ![](https://www.gifpng.com/64x64/161717/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#161717 | ![](https://www.gifpng.com/64x64/161717/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#161717 |
| <pre>--p-shadow-from-direct-light</pre>  | For use in building shadows for popovers, cards, and modals. This color has an alpha of `0.15`.                                       | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#000000 | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#000000 |
| <pre>--p-hint-from-direct-light</pre>    | For use in building shadows scrollables.                                                                                              | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#000000 | ![](https://www.gifpng.com/64x64/bababa/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#bababa |

---

## onSurface

[↑ Back to top](#table-of-contents)

The onSurface role is made up of elements which appear on top of a surface, including borders, secondary icons, and text. When a light surface is provided, onSurface values will be dark. When a dark surface is provided, onSurface values will be light.

| CSS variable                   | Description                                                  | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ------------------------------ | ------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border</pre>          | For use as a border (border or interactive outline).         | ![](https://www.gifpng.com/64x64/b5babf/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#b5babf | ![](https://www.gifpng.com/64x64/515458/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#515458 |
| <pre>--p-border-disabled</pre> | For use as a an interactive outline on disabled elements.    | ![](https://www.gifpng.com/64x64/f1f2f3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#f1f2f3 | ![](https://www.gifpng.com/64x64/a5abb1/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#a5abb1 |
| <pre>--p-border-subdued</pre>  | For use as a subdued border (border or interactive outline). | ![](https://www.gifpng.com/64x64/d3d6d9/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#d3d6d9 | ![](https://www.gifpng.com/64x64/4a4d4f/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#4a4d4f |
| <pre>--p-icon</pre>            | For use as the fill color of secondary icons.                | ![](https://www.gifpng.com/64x64/5c5e61/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#5c5e61 | ![](https://www.gifpng.com/64x64/a5abb1/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#a5abb1 |
| <pre>--p-icon-disabled</pre>   | For use as the fill color of disabled secondary icons.       | ![](https://www.gifpng.com/64x64/bbbfc4/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#bbbfc4 | ![](https://www.gifpng.com/64x64/545759/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#545759 |
| <pre>--p-icon-subdued</pre>    | For use as the fill color of subdued secondary icons.        | ![](https://www.gifpng.com/64x64/8c9197/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#8c9197 | ![](https://www.gifpng.com/64x64/787d82/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#787d82 |
| <pre>--p-text</pre>            | For use as a secondary text color.                           | ![](https://www.gifpng.com/64x64/202222/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#202222 | ![](https://www.gifpng.com/64x64/e3e6e8/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#e3e6e8 |
| <pre>--p-text-disabled</pre>   | For use as a disabled secondary text color.                  | ![](https://www.gifpng.com/64x64/8f9499/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#8f9499 | ![](https://www.gifpng.com/64x64/6f7376/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#6f7376 |
| <pre>--p-text-subdued</pre>    | For use as a subdued secondary text color.                   | ![](https://www.gifpng.com/64x64/6c7075/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#6c7075 | ![](https://www.gifpng.com/64x64/989fa4/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#989fa4 |

---

## interactive

[↑ Back to top](#table-of-contents)

The interactive role is used to express interactivity in components. It is used in links, as an indicator of focus, and as an indicator of selected interactive states.

| CSS variable                               | Description                                                                                                                        | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ------------------------------------------ | ---------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-action-interactive</pre>          | Used for links and plain buttons.                                                                                                  | ![](https://www.gifpng.com/64x64/2d72d2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#2d72d2 | ![](https://www.gifpng.com/64x64/38a5ff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#38a5ff |
| <pre>--p-action-interactive-disabled</pre> | Used for disabled links and plain buttons.                                                                                         | ![](https://www.gifpng.com/64x64/4a8af2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#4a8af2 | ![](https://www.gifpng.com/64x64/2662b5/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#2662b5 |
| <pre>--p-action-interactive-hovered</pre>  | Used for hovered links and plain buttons.                                                                                          | ![](https://www.gifpng.com/64x64/2156a1/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#2156a1 | ![](https://www.gifpng.com/64x64/66adff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#66adff |
| <pre>--p-action-interactive-subdued</pre>  | Used for subdued links and plain buttons.                                                                                          | ![](https://www.gifpng.com/64x64/3279dc/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#3279dc | ![](https://www.gifpng.com/64x64/3074d5/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#3074d5 |
| <pre>--p-action-interactive-pressed</pre>  | Used for pressed links and plain buttons.                                                                                          | ![](https://www.gifpng.com/64x64/1a4889/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#1a4889 | ![](https://www.gifpng.com/64x64/8abdff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#8abdff |
| <pre>--p-focused</pre>                     | For use in the focus ring on interactive elements.                                                                                 | ![](https://www.gifpng.com/64x64/4a8af2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#4a8af2 | ![](https://www.gifpng.com/64x64/2662b5/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#2662b5 |
| <pre>--p-surface-selected</pre>            | For use as a surface color in selected interactive elements, in components such as option list and resource list.                  | ![](https://www.gifpng.com/64x64/f1f4fe/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#f1f4fe | ![](https://www.gifpng.com/64x64/020e22/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#020e22 |
| <pre>--p-surface-selected-hovered</pre>    | For use as a surface color in selected interactive elements that are hovered, in components such as option list and resource list. | ![](https://www.gifpng.com/64x64/d4defc/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#d4defc | ![](https://www.gifpng.com/64x64/071c3b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#071c3b |
| <pre>--p-surface-selected-pressed</pre>    | For use as a surface color in selected interactive elements that are pressed, in components such as option list and resource list. | ![](https://www.gifpng.com/64x64/b9c9f9/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#b9c9f9 | ![](https://www.gifpng.com/64x64/0d2a54/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#0d2a54 |
| <pre>--p-icon-on-interactive</pre>         | For use as a fill color for icons on interactive elements.                                                                         | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ffffff |

---

## secondary

[↑ Back to top](#table-of-contents)

A secondary interactive color role, for use in secondary and tertiary buttons as a background color, as well as in form elements as a background color.

| CSS variable                             | Description                                                                                                                                   | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ---------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-action-secondary</pre>          | Used for secondary buttons and tertiary buttons, as well as in form elements as a background color and pontentially other secondary surfaces. | ![](https://www.gifpng.com/64x64/eaebec/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#eaebec | ![](https://www.gifpng.com/64x64/333638/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#333638 |
| <pre>--p-action-secondary-disabled</pre> | Used as a disabled state for secondary buttons                                                                                                | ![](https://www.gifpng.com/64x64/ecedee/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ecedee | ![](https://www.gifpng.com/64x64/202222/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#202222 |
| <pre>--p-action-secondary-hovered</pre>  | Used as a hovered state for secondary buttons                                                                                                 | ![](https://www.gifpng.com/64x64/e1e3e5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#e1e3e5 | ![](https://www.gifpng.com/64x64/53565a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#53565a |
| <pre>--p-action-secondary-pressed</pre>  | Used as a pressed state for secondary buttons                                                                                                 | ![](https://www.gifpng.com/64x64/d9dbde/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#d9dbde | ![](https://www.gifpng.com/64x64/5f6467/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#5f6467 |
| <pre>--p-border-secondary</pre>          | Used for borders on form elements                                                                                                             | ![](https://www.gifpng.com/64x64/b5babf/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#b5babf | ![](https://www.gifpng.com/64x64/515458/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#515458 |
| <pre>--p-border-secondary-hovered</pre>  | Used for borders on hovered form elements                                                                                                     | ![](https://www.gifpng.com/64x64/989ea4/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#989ea4 | ![](https://www.gifpng.com/64x64/515458/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#515458 |
| <pre>--p-border-secondary-disabled</pre> | Used for disabled borders on form elements                                                                                                    | ![](https://www.gifpng.com/64x64/d3d6d9/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#d3d6d9 | ![](https://www.gifpng.com/64x64/676b6f/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#676b6f |

---

## primary

[↑ Back to top](#table-of-contents)

A primary interactive color, for use in primary buttons as a background color. Also used in navigation and tabs for icons, and for a surface color when in a selected state.

| CSS variable                            | Description                                                                                                                                                             | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| --------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-action-primary</pre>           | Used as the background color for primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.          | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#008060 | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#008060 |
| <pre>--p-action-primary-disabled</pre>  | Used as the background color for disabled primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states. | ![](https://www.gifpng.com/64x64/005741/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#005741 | ![](https://www.gifpng.com/64x64/005741/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#005741 |
| <pre>--p-action-primary-hovered</pre>   | Used as the background color for hovered primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.  | ![](https://www.gifpng.com/64x64/007054/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#007054 | ![](https://www.gifpng.com/64x64/00946f/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#00946f |
| <pre>--p-action-primary-pressed</pre>   | Used as the background color for pressed primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.  | ![](https://www.gifpng.com/64x64/006149/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#006149 | ![](https://www.gifpng.com/64x64/00a37a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#00a37a |
| <pre>--p-icon-on-primary</pre>          | For use as a fill color for icons on primary actions. Not for use in icons on navigation and tabs.                                                                      | ![](https://www.gifpng.com/64x64/e5fff4/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#e5fff4 | ![](https://www.gifpng.com/64x64/e5fff4/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#e5fff4 |
| <pre>--p-text-on-primary</pre>          | For use as a text color on primary actions. Not for use in text on navigation and tabs.                                                                                 | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ffffff |
| <pre>--p-primary-selected</pre>         | Used as a surface color to indicate selected interactive states in navigation and tabs.                                                                                 | ![](https://www.gifpng.com/64x64/e1f5ec/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#e1f5ec | ![](https://www.gifpng.com/64x64/0c1210/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#0c1210 |
| <pre>--p-primary-selected-hovered</pre> | Used as a surface color to indicate selected interactive states that are hovered in navigation and tabs.                                                                | ![](https://www.gifpng.com/64x64/b3d0c3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#b3d0c3 | ![](https://www.gifpng.com/64x64/272f2b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#272f2b |
| <pre>--p-primary-selected-pressed</pre> | Used as a surface color to indicate selected interactive states that are pressed in navigation and tabs.                                                                | ![](https://www.gifpng.com/64x64/a3bdb1/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#a3bdb1 | ![](https://www.gifpng.com/64x64/363f3b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#363f3b |

---

## critical

[↑ Back to top](#table-of-contents)

Used to communicate destructive outcomes on interactive elements, for communicating errors, and to indicate a critical event in inert elements that requires immediate merchant action.

| CSS variable                                    | Description                                                                                                                                                          | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ----------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border-critical</pre>                  | For use as a border on critical components such as banners, and as an outline on interactive elements in an error state.                                             | ![](https://www.gifpng.com/64x64/e12e0e/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#e12e0e | ![](https://www.gifpng.com/64x64/e12e0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#e12e0e |
| <pre>--p-border-critical-disabled</pre>         | For use as a disabled border on critical components such as banners, and as an outline on interactive elements in an error state.                                    | ![](https://www.gifpng.com/64x64/febcb9/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#febcb9 | ![](https://www.gifpng.com/64x64/811704/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#811704 |
| <pre>--p-icon-critical</pre>                    | For use as an icon fill color on top of critical elements.                                                                                                           | ![](https://www.gifpng.com/64x64/eb300f/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#eb300f | ![](https://www.gifpng.com/64x64/d92b0d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#d92b0d |
| <pre>--p-surface-critical</pre>                 | For use as a surface color on critical elements including badges.                                                                                                    | ![](https://www.gifpng.com/64x64/fffafa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fffafa | ![](https://www.gifpng.com/64x64/460701/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#460701 |
| <pre>--p-surface-critical-subdued</pre>         | For use as a subdued surface color on critical elements including banners.                                                                                           | ![](https://www.gifpng.com/64x64/fff6f5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fff6f5 | ![](https://www.gifpng.com/64x64/460701/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#460701 |
| <pre>--p-surface-critical-subdued-hovered</pre> | For use as a surface color on critical interactive elements including action list items in a hovered state.                                                          | ![](https://www.gifpng.com/64x64/fff0f0/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fff0f0 | ![](https://www.gifpng.com/64x64/431714/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#431714 |
| <pre>--p-surface-critical-subdued-pressed</pre> | For use as a surface color on critical interactive elements including action list items in a pressed state.                                                          | ![](https://www.gifpng.com/64x64/fed4d2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fed4d2 | ![](https://www.gifpng.com/64x64/6d1103/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#6d1103 |
| <pre>--p-text-critical</pre>                    | For use as a text color in inert critical elements such as exception list. Not for use as a text color on banners and badges.                                        | ![](https://www.gifpng.com/64x64/d92b0d/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#d92b0d | ![](https://www.gifpng.com/64x64/ea817b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ea817b |
| <pre>--p-action-critical</pre>                  | For use as the background color for destructive buttons, and as the background color for error toast messages.                                                       | ![](https://www.gifpng.com/64x64/d92b0d/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#d92b0d | ![](https://www.gifpng.com/64x64/cf290c/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#cf290c |
| <pre>--p-action-critical-disabled</pre>         | For use as the background color for disabled destructive buttons, and as the background color for error toast messages.                                              | ![](https://www.gifpng.com/64x64/fd4f3f/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fd4f3f | ![](https://www.gifpng.com/64x64/bd250a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#bd250a |
| <pre>--p-action-critical-hovered</pre>          | For use as the background color for hovered destructive buttons, and as the background color for error toast messages.                                               | ![](https://www.gifpng.com/64x64/c2260a/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#c2260a | ![](https://www.gifpng.com/64x64/e12e0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#e12e0e |
| <pre>--p-action-critical-pressed</pre>          | For use as the background color for pressed destructive buttons, and as the background color for error toast messages.                                               | ![](https://www.gifpng.com/64x64/aa2008/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#aa2008 | ![](https://www.gifpng.com/64x64/fa320f/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#fa320f |
| <pre>--p-icon-on-critical</pre>                 | For use as a fill color for icons on critical actions.                                                                                                               | ![](https://www.gifpng.com/64x64/fff6f5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fff6f5 | ![](https://www.gifpng.com/64x64/fff6f5/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#fff6f5 |
| <pre>--p-text-on-critical</pre>                 | For use as a text color on critical actions.                                                                                                                         | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ffffff | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ffffff |
| <pre>--p-link-critical</pre>                    | For use as a text color in destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges.          | ![](https://www.gifpng.com/64x64/dd2d0e/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#dd2d0e | ![](https://www.gifpng.com/64x64/fd7068/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#fd7068 |
| <pre>--p-link-critical-disabled</pre>           | For use as a text color in disabled destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges. | ![](https://www.gifpng.com/64x64/fd918b/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fd918b | ![](https://www.gifpng.com/64x64/feada9/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#feada9 |
| <pre>--p-link-critical-hovered</pre>            | For use as a text color in hovered destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges.  | ![](https://www.gifpng.com/64x64/cf290c/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#cf290c | ![](https://www.gifpng.com/64x64/fd8881/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#fd8881 |
| <pre>--p-link-critical-pressed</pre>            | For use as a text color in pressed destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges.  | ![](https://www.gifpng.com/64x64/680f03/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#680f03 | ![](https://www.gifpng.com/64x64/fd9e9b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#fd9e9b |

---

## warning

[↑ Back to top](#table-of-contents)

For use as an indicator that action should be taken by merchants in components including badges, banners, and exception lists.

| CSS variable                           | Description                                                                                                                   | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| -------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border-warning</pre>          | For use as a border on warning components such as banners.                                                                    | ![](https://www.gifpng.com/64x64/f0b400/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#f0b400 | ![](https://www.gifpng.com/64x64/997000/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#997000 |
| <pre>--p-icon-warning</pre>            | For use as an icon fill color on top of warning elements.                                                                     | ![](https://www.gifpng.com/64x64/cc9600/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#cc9600 | ![](https://www.gifpng.com/64x64/664900/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#664900 |
| <pre>--p-surface-warning</pre>         | For use as a surface color on warning elements including badges.                                                              | ![](https://www.gifpng.com/64x64/ffcd75/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ffcd75 | ![](https://www.gifpng.com/64x64/997000/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#997000 |
| <pre>--p-surface-warning-subdued</pre> | For use as a subdued surface color on warning elements including banners.                                                     | ![](https://www.gifpng.com/64x64/fff1e0/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fff1e0 | ![](https://www.gifpng.com/64x64/4e3c1d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#4e3c1d |
| <pre>--p-text-warning</pre>            | For use as a text color in inert critical elements such as exception list. Not for use as a text color on banners and badges. | ![](https://www.gifpng.com/64x64/8f6900/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#8f6900 | ![](https://www.gifpng.com/64x64/cc9600/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#cc9600 |

---

## highlight

[↑ Back to top](#table-of-contents)

Used to highlight elements of the UI that are important for merchants, but do not require immediate action. Used in information banners and badges, indicators that draw attention to new information, bars that indicate loading or progress, and in data visualization.

| CSS variable                             | Description                                                                                                 | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| ---------------------------------------- | ----------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border-highlight</pre>          | For use as a border on informational components such as banners.                                            | ![](https://www.gifpng.com/64x64/449da7/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#449da7 | ![](https://www.gifpng.com/64x64/449da7/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#449da7 |
| <pre>--p-icon-highlight</pre>            | For use as an icon fill color on top of informational elements.                                             | ![](https://www.gifpng.com/64x64/41969f/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#41969f | ![](https://www.gifpng.com/64x64/2b6c73/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#2b6c73 |
| <pre>--p-surface-highlight</pre>         | For use as a surface color on information elements including badges.                                        | ![](https://www.gifpng.com/64x64/8ee0eb/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#8ee0eb | ![](https://www.gifpng.com/64x64/006970/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#006970 |
| <pre>--p-surface-highlight-subdued</pre> | For use as a surface color on information elements including banners.                                       | ![](https://www.gifpng.com/64x64/f6fdfe/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#f6fdfe | ![](https://www.gifpng.com/64x64/12363a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#12363a |
| <pre>--p-text-highlight</pre>            | For use as a text color in inert informational elements. Not for use as a text color on banners and badges. | ![](https://www.gifpng.com/64x64/081f21/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#081f21 | ![](https://www.gifpng.com/64x64/a3effa/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#a3effa |

---

## success

[↑ Back to top](#table-of-contents)

Used to indicate the result of a successful action taken by a merchant, to indicate a positive event, or to illustrate growth.

| CSS variable                           | Description                                                                                           | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| -------------------------------------- | ----------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-border-success</pre>          | For use as a border on success components such as banners.                                            | ![](https://www.gifpng.com/64x64/008563/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#008563 | ![](https://www.gifpng.com/64x64/008563/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#008563 |
| <pre>--p-icon-success</pre>            | For use as an icon fill color on top of success elements.                                             | ![](https://www.gifpng.com/64x64/004231/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#004231 | ![](https://www.gifpng.com/64x64/005c45/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#005c45 |
| <pre>--p-surface-success</pre>         | For use as a surface color on success elements including badges.                                      | ![](https://www.gifpng.com/64x64/8ae5c2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#8ae5c2 | ![](https://www.gifpng.com/64x64/005c45/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#005c45 |
| <pre>--p-surface-success-subdued</pre> | For use as a surface color on information elements including banners.                                 | ![](https://www.gifpng.com/64x64/f6fefa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#f6fefa | ![](https://www.gifpng.com/64x64/1c352c/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#1c352c |
| <pre>--p-text-success</pre>            | For use as a text color in inert success elements. Not for use as a text color on banners and badges. | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#008060 | ![](https://www.gifpng.com/64x64/58ad8d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#58ad8d |

---

## decorative

[↑ Back to top](#table-of-contents)

Used to decorate elements where color does convey a specific meaning in components like avatars

| CSS variable                            | Description                                                                 | Light mode                                                                                                                      | Dark mode                                                                                                                       |
| --------------------------------------- | --------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
| <pre>--p-decorative-one-surface</pre>   | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/ffc96b/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ffc96b | ![](https://www.gifpng.com/64x64/906709/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#906709 |
| <pre>--p-decorative-one-text</pre>      | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/3d2800/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#3d2800 | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ffffff |
| <pre>--p-decorative-two-surface</pre>   | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/ffc6b3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#ffc6b3 | ![](https://www.gifpng.com/64x64/cc5814/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#cc5814 |
| <pre>--p-decorative-two-text</pre>      | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/470b1b/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#470b1b | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ffffff |
| <pre>--p-decorative-three-surface</pre> | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/91e3b3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#91e3b3 | ![](https://www.gifpng.com/64x64/007a5a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#007a5a |
| <pre>--p-decorative-three-text</pre>    | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/002e18/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#002e18 | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ffffff |
| <pre>--p-decorative-four-surface</pre>  | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/90e0d5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#90e0d5 | ![](https://www.gifpng.com/64x64/167e7a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#167e7a |
| <pre>--p-decorative-four-text</pre>     | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/002e2e/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#002e2e | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ffffff |
| <pre>--p-decorative-five-surface</pre>  | For use as a decorative surface color.                                      | ![](https://www.gifpng.com/64x64/fdc9d0/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#fdc9d0 | ![](https://www.gifpng.com/64x64/c13357/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#c13357 |
| <pre>--p-decorative-five-text</pre>     | For use as a decorative text color that is applied on a decorative surface. | ![](https://www.gifpng.com/64x64/4e0e1f/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20)<br />#4e0e1f | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20)<br />#ffffff |

---

## Overrides

[↑ Back to top](#table-of-contents)

| CSS variable                                  | Value                                                                                             |
| --------------------------------------------- | ------------------------------------------------------------------------------------------------- |
| `--p-border-radius-base`                      | `0.4rem`                                                                                          |
| `--p-border-radius-wide`                      | `0.8rem`                                                                                          |
| `--p-card-shadow`                             | `0px 0px 5px var(--p-shadow-from-ambient-light), 0px 1px 2px var(--p-shadow-from-direct-light)`   |
| `--p-popover-shadow`                          | `-1px 0px 20px var(--p-shadow-from-ambient-light), 0px 1px 5px var(--p-shadow-from-direct-light)` |
| `--p-modal-shadow`                            | `0px 6px 32px var(--p-shadow-from-ambient-light), 0px 1px 6px var(--p-shadow-from-direct-light)`  |
| `--p-override-none`                           | `none`                                                                                            |
| `--p-override-transparent`                    | `transparent`                                                                                     |
| `--p-override-one`                            | `1`                                                                                               |
| `--p-override-visible`                        | `visible`                                                                                         |
| `--p-override-zero`                           | `0`                                                                                               |
| `--p-override-loading-z-index`                | `514`                                                                                             |
| `--p-button-font-weight`                      | `500`                                                                                             |
| `--p-non-null-content`                        | `''`                                                                                              |
| `--p-choice-size`                             | `2rem`                                                                                            |
| `--p-choice-margin`                           | `0.1rem`                                                                                          |
| `--p-banner-border-default`                   | `inset 0 0.2rem 0 0 var(--p-border), inset 0 0 0 0.2rem var(--p-border)`                          |
| `--p-banner-border-success`                   | `inset 0 0.2rem 0 0 var(--p-border-success), inset 0 0 0 0.2rem var(--p-border-success)`          |
| `--p-banner-border-highlight`                 | `inset 0 0.2rem 0 0 var(--p-border-highlight), inset 0 0 0 0.2rem var(--p-border-highlight)`      |
| `--p-banner-border-warning`                   | `inset 0 0.2rem 0 0 var(--p-border-warning), inset 0 0 0 0.2rem var(--p-border-warning)`          |
| `--p-banner-border-critical`                  | `inset 0 0.2rem 0 0 var(--p-border-critical), inset 0 0 0 0.2rem var(--p-border-critical)`        |
| `--p-badge-mix-blend-mode`                    | `luminosity`                                                                                      |
| `--p-thin-border-subdued`                     | `0.1rem solid var(--p-border-subdued)`                                                            |
| `--p-text-field-spinner-offset`               | `0.2rem`                                                                                          |
| `--p-text-field-focus-ring-offset`            | `-0.4rem`                                                                                         |
| `--p-text-field-focus-ring-border-radius`     | `0.7rem`                                                                                          |
| `--p-checkbox-radio-button-focus-ring-offset` | `0.3rem`                                                                                          |
| `--p-button-group-item-spacing`               | `0.2rem`                                                                                          |
| `--p-duration-1-0-0`                          | `100ms`                                                                                           |
| `--p-duration-1-5-0`                          | `150ms`                                                                                           |
| `--p-ease-in`                                 | `cubic-bezier(0.5, 0.1, 1, 1)`                                                                    |
| `--p-ease`                                    | `cubic-bezier(0.4, 0.22, 0.28, 1)`                                                                |
